## Note: Files in this directory are old test cases that accumulated
## historically over time, many of them commented out for time reasons
## (and unorganized due to lack of anything close to testthat at the
## time of creation). The testthat sub-directory now contains a
## selected subset of these tests (with some additions) that have been
## brought in the testthat format.

library(testthat)
library(DoseFinding)

test_check("DoseFinding")
